unit MainNote;

interface

uses Classes, Controls, Forms, StdCtrls, Spin;

type
  TMainNoteForm = class(TForm)
    NotesLB: TListBox;
    NoteAddBtn: TButton;
    NoteEditBtn: TButton;
    NoteDeleteBtn: TButton;
    Label4: TLabel;
    ServerEd: TEdit;
    GroupBox2: TGroupBox;
    DSEd: TEdit;
    Label3: TLabel;
    StoreBtn: TButton;
    Label5: TLabel;
    Label1: TLabel;
    Label2: TLabel;
    ConnectBtn: TButton;
    CheckBox1: TCheckBox;
    ProxyEd: TEdit;
    PortEd: TSpinEdit;
    UserNameEd: TEdit;
    PasswordEd: TEdit;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConnectBtnClick(Sender: TObject);
    procedure NotesLBClick(Sender: TObject);
    procedure NoteAddBtnClick(Sender: TObject);
    procedure NoteEditBtnClick(Sender: TObject);
    procedure NoteDeleteBtnClick(Sender: TObject);
    procedure StoreBtnClick(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
  private
    procedure UpdateNotes;
    procedure UpdateNoteButtons;
  end;

var
  MainNoteForm: TMainNoteForm;

implementation

uses SysUtils, EditNote, NoteSyncML, SyncMLBase;

{$R *.dfm}

var
  SMLNotes: TSMLNotes;

procedure TMainNoteForm.FormCreate(Sender: TObject);
begin
  SMLNotes := TSMLNotes.Create;
//  SMLNotes.LogFileName := 'NoteSyncML.log';
end;

procedure TMainNoteForm.FormDestroy(Sender: TObject);
begin
  SMLNotes.Free;
end;

procedure TMainNoteForm.UpdateNotes;
var
  I: Integer;
begin
  NotesLB.Clear;
  Screen.Cursor := crHourGlass;
  try
    for I := 0 to SMLNotes.NoteCount - 1 do
      with SMLNotes.Notes[I] do
        if LocalItemState <> isDeleted then
          NotesLB.Items.Add(Title);
  finally
    Screen.Cursor := crDefault;
  end;
  UpdateNoteButtons;
end;

procedure TMainNoteForm.UpdateNoteButtons;
begin
  NoteEditBtn.Enabled := NotesLB.ItemIndex >= 0;
  NoteDeleteBtn.Enabled := NotesLB.ItemIndex >= 0;
end;

procedure TMainNoteForm.ConnectBtnClick(Sender: TObject);
begin
  NoteAddBtn.Enabled := False;
  NotesLB.Items.Clear;
  Application.ProcessMessages;
  if not CheckBox1.Checked then
  begin
    SMLNotes.ProxyServer := ProxyEd.Text;
    SMLNotes.ProxyPort := PortEd.Value;
  end
  else
  begin
    SMLNotes.ProxyServer := '';
    SMLNotes.ProxyPort := 0;
  end;
  SMLNotes.BaseURL := ServerEd.Text;
  SMLNotes.UserName := UserNameEd.Text;
  SMLNotes.Password := PasswordEd.Text;
  SMLNotes.DataSource := DSEd.Text;
  SMLNotes.Load;
  NoteAddBtn.Enabled := True;
  UpdateNotes;
  ConnectBtn.Caption := 'Refresh';
  StoreBtn.Enabled := False;
  UpdateNoteButtons;
end;

procedure TMainNoteForm.NotesLBClick(Sender: TObject);
begin
  UpdateNoteButtons;
end;

procedure TMainNoteForm.NoteAddBtnClick(Sender: TObject);
begin
  EditNoteForm.Note := SMLNotes.NewNote;
  if EditNoteForm.ShowModal = mrOK then
  begin
    NotesLB.Items.Add(EditNoteForm.Note.Title);
    UpdateNoteButtons;
    StoreBtn.Enabled := True;
  end
  else
    SMLNotes.DeleteNote(SMLNotes.NoteCount - 1);
end;

procedure TMainNoteForm.NoteEditBtnClick(Sender: TObject);
begin
  EditNoteForm.Note := SMLNotes.Notes[NotesLB.ItemIndex];
  if EditNoteForm.ShowModal = mrOK then
  begin
    NotesLB.Items[NotesLB.ItemIndex] := EditNoteForm.Note.Title;
    StoreBtn.Enabled := True;
  end;
end;

procedure TMainNoteForm.NoteDeleteBtnClick(Sender: TObject);
begin
  SMLNotes.DeleteNote(NotesLB.ItemIndex);
  NotesLB.Items.Delete(NotesLB.ItemIndex);
  UpdateNoteButtons;
  StoreBtn.Enabled := True;
end;

procedure TMainNoteForm.StoreBtnClick(Sender: TObject);
begin
  SMLNotes.Store;
  UpdateNotes;
  StoreBtn.Enabled := false;
end;

procedure TMainNoteForm.CheckBox1Click(Sender: TObject);
begin
  ProxyEd.Enabled := CheckBox1.Checked;
  PortEd.Enabled := ProxyEd.Enabled;
end;

end.

